import setuptools

setuptools.setup(
    name='chromeprinter',
    version='0.0.1',
    packages=setuptools.find_packages(),
    url='',
    author='OLixao',
    install_requires=['selenium'],
    author_email='contact@olixao.ml',
    description='Print chome page with chromedriver',
    long_description='none',
    long_description_content_type="text/markdown"
)
